@@ -1,9 +1,11 @@
-#!/usr/local/bin/perl -w
 
 #
 # Copyright (C) 1995, 1996 Systemics Ltd (http://www.systemics.com/)
 # All rights reserved.
 #
+# $Revision: 1.2 $
+# $State: Exp $
+#
 
 package Stream::StringInput;
 
@@ -34,7 +36,8 @@ sub new
 
 	my $type = shift; my $self = {}; bless $self, $type;
 
-	$self->{'data'} = shift || return "Undefined parameter";
+	$self->{'data'} = shift;
+	defined $self->{'data'} || return "Undefined parameter";
 
 	$self;
 }
@@ -46,6 +49,8 @@ sub read
 	my $self = shift;
 	my $count = shift;
 
+	return if (length($self->{'data'}) == 0);
+
 	my $retval = substr($self->{'data'}, 0, $count);
 	substr($self->{'data'}, 0, $count) = '';
 	$retval;
