@@ -1,9 +1,11 @@
-#!/usr/local/bin/perl -w
 
 #
 # Copyright (C) 1995, 1996 Systemics Ltd (http://www.systemics.com/)
 # All rights reserved.
 #
+# $Revision: 1.2 $
+# $State: Exp $
+#
 
 package Stream::StringOutput;
 
@@ -42,7 +44,8 @@ sub write
 	usage("data") unless @_ == 2;
 
 	my $self = shift;
-	my $data = shift || usage("data");
+	my $data = shift;
+	defined $data || usage("data");
 
 	$self->{'data'} .= $data;
 }
